#! /usr/bin/env bash

CD_DNS_SERVERS=(
'9.9.9.9'
)
CD_REPOSITORY='rwx.work/cd'

CD_DNS_FILE='/etc/resolv.conf'
case "${CD_OS_NAME}" in
    'debian')
        case "${CD_OS_VERSION}" in
            'bookworm')
                echo 'bookworm!'
            ;;
            *)
                echo 'CD_OS_VERSION'
                exit 2
            ;;
        esac
    ;;
    *)
        echo 'CD_OS_NAME'
        exit 1
    ;;
esac
CD_STEP=0

function cd_step {
    if [ "${1}" ] ; then
        ((CD_STEP++))
        echo "
 ↕ ${CD_STEP} ↔ ${1}
"
    fi
}

function cd_write {
local file="${1}"
local text="${2}"
    if [ "${file}" ] ; then
        echo -n "${text}" \
        > "${file}" \
        || exit
    fi
}

function cd_set_dns_resolving {
local server
local text=''
    cd_step "set name servers"
    for server in "${CD_DNS_SERVERS[@]}" ; do
        text+="nameserver ${server}
"
    done
    cd_write "${CD_DNS_FILE}" "${text}" \
    || exit
}

function cd_set_packages_configuration {
    cd_step "configure package manager"
    case "${CD_OS_NAME}" in
        'debian')
    cd_write '/etc/apt/apt.conf.d/apt.conf' "\
Acquire::Check-Valid-Until True;
APT::Get::Show-Versions True;
APT::Install-Recommends False;
APT::Install-Suggests False;
Dir::Etc::SourceParts '';
"
        ;;
        *) exit 1 ;;
    esac
}

function cd_main {
    cd_set_dns_resolving
    cd_set_packages_configuration

cd_step "configure package repositories"
echo -n "\
deb https://deb.debian.org/debian bookworm main
deb https://deb.debian.org/debian bookworm-backports main
deb https://deb.debian.org/debian bookworm-updates main
deb https://deb.debian.org/debian-security bookworm-security main
" > '/etc/apt/sources.list' \
|| exit

cd_step "disable package verification"
echo -n "\
Acquire::https::Verify-Peer False;
" > '/etc/apt/apt.conf.d/https' \
|| exit
cd_step "update package catalog"
apt-get update \
|| exit
cd_step "install CA certificates package"
apt-get install --yes 'ca-certificates' \
|| exit
cd_step "enable package verification"
rm '/etc/apt/apt.conf.d/https' \
|| exit

cd_step "update package catalog"
apt-get update \
|| exit
cd_step "upgrade packages"
apt-get upgrade --yes \
|| exit

cd_step "install Git"
apt-get install --yes 'git' \
|| exit

DIRECTORY="$(mktemp --directory)" \
|| exit
cd_step "clone Continuous Delivery"
git clone \
"${GITHUB_SERVER_URL}/${CD_REPOSITORY}" \
"${DIRECTORY}" \
|| exit

cd_step "install Python"
apt-get install --yes 'python3' \
|| exit
cd_step "clean package cache"
apt-get clean \
|| exit
cd_step "bootstrap"
"${DIRECTORY}/bootstrap.sh"

}

cd_main
